#ifndef __PFE_PFE_BASE_H
#define __PFE_PFE_BASE_H
/** 
 * -- declare prototypes of the base system
 * 
 *  Copyright (C) Tektronix, Inc. 1998 - 2003.
 *  Copyright (C) 2005 - 2008 Guido U. Draheim <guidod@gmx.de>
 *
 *  @see     GNU LGPL
 *  @author  Guido U. Draheim            (modified by $Author: guidod $)
 *  @version $Revision: 1.3 $
 *     (modified $Date: 2008/04/20 04:46:30 $)
 *
 *  @description
 *            most of the routines of the internal forth system
 *            are declared here
 */
/*@{*/

#include <pfe/pfe-ext.h>

#include <pfe/core-sub.h>
#include <pfe/core-ext.h>
#include <pfe/core-mix.h>
#include <pfe/dict-sub.h>
#include <pfe/dict-comp.h>
#include <pfe/header-sub.h>
#include <pfe/block-sub.h>
#include <pfe/block-ext.h>
#include <pfe/engine-sub.h>
#include <pfe/engine-set.h>
#include <pfe/exception-sub.h>
#include <pfe/memory-sub.h>
#include <pfe/misc-ext.h>
#include <pfe/option-ext.h>
#include <pfe/option-set.h>
#include <pfe/search-order-ext.h>
#include <pfe/signals-ext.h>
#include <pfe/tools-sub.h>
#include <pfe/tools-mix.h>

/*@}*/
#endif
